# BreezyHR Connector

## About BreezyHR :

BreezyHR is a recruiting software that simplifies the process of attracting and hiring top talent. It offers a range of tools and features to make the hiring process more efficient and effective.

## Connector features :

- **Push profiles :**  Retrieves profiles from HrFlow Souce export API and sends them to BreezyHR ATS
- **Pull Jobs :** Retrieves jobs from Workable vacancies export API  and sends them to a [HrFlow.ai](http://HrFlow.ai) Board

**Useful links:**

📄Visit [BreezyHR](https://breezy.hr) to learn more.

💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/breezyhr) on our Github.

**Screenshots :**

- **Push profiles :**
    
![image](https://user-images.githubusercontent.com/55802491/210259113-9ed32efa-066f-4ccf-b440-c4383b83325d.png)
    
- **Pull Jobs :**
    
![image](https://user-images.githubusercontent.com/55802491/210259130-5fc9d163-29aa-47ed-9d19-0559385e4edc.png)
